package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.RoleMapper;
import com.datacloudsec.scan.entity.Perm;
import com.datacloudsec.scan.entity.Role;
import com.datacloudsec.scan.service.IRole;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/RoleService.class */
public class RoleService implements IRole {
    private RoleMapper roleMapper = (RoleMapper) InstanceUtil.newDaoInstance(RoleMapper.class);

    public List<Map<String, Object>> search() throws Exception {
        return this.roleMapper.search();
    }

    @Transactional
    public int delete(Integer id, Integer version) throws Exception {
        if (id.intValue() == 1 || id.intValue() == 2 || id.intValue() == 3) {
            throw new UEException("系统默认角色不允许删除！");
        }
        int count = this.roleMapper.getUcountByRid(id);
        if (count > 0) {
            throw new UEException("此角色已关联用户，请先用户管理中移除此角色！");
        }
        this.roleMapper.deleteRolePermission(id);
        Integer rcount = Integer.valueOf(this.roleMapper.delete(id, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        return 0;
    }

    @Transactional
    public void updateRole(Integer id, String name, String desct, String permissionId, Integer version, Integer ruleId) throws Exception {
        int count = this.roleMapper.getRoleCountByName(name, id);
        if (count > 0) {
            throw new UEException("角色【" + name + "】已存在！");
        }
        if (id.intValue() == 1) {
            throw new UEException("管理员角色不允许删除！");
        }
        Role role = new Role();
        role.setId(id);
        role.setName(name);
        role.setDesct(desct);
        role.setRuleId(ruleId);
        role.setVersion(version);
        Integer rcount = Integer.valueOf(this.roleMapper.update(role));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        this.roleMapper.deleteRolePermission(id);
        if (StringUtils.isNotBlank(permissionId)) {
            String[] permissionIds = permissionId.split(",");
            for (String pid : permissionIds) {
                this.roleMapper.insertPermission(id, Integer.valueOf(ObjectUtil.getInt(pid, 0)));
            }
        }
    }

    @Transactional
    public void inserRole(String name, String desct, String permissionId, Integer ruleId) throws Exception {
        int count = this.roleMapper.getRoleCountByName(name, (Integer) null);
        if (count > 0) {
            throw new UEException("角色名称【" + name + "】已存在！");
        }
        Role role = new Role();
        role.setName(name);
        role.setDesct(desct);
        role.setRuleId(ruleId);
        this.roleMapper.insert(role);
        if (StringUtils.isNotBlank(permissionId)) {
            String[] permissionIds = permissionId.split(",");
            for (String pid : permissionIds) {
                this.roleMapper.insertPermission(role.getId(), Integer.valueOf(ObjectUtil.getInt(pid, 0)));
            }
        }
    }

    public List<Map<String, Object>> getPermission() throws Exception {
        return this.roleMapper.getPermission();
    }

    public List<String> getPermissionTreeByRId(Integer rid) throws Exception {
        return this.roleMapper.getPermissionTreeByRId(rid);
    }

    public Role getRoleById(Integer id) throws Exception {
        return this.roleMapper.getRoleById(id);
    }

    @Transactional
    public void updatePersissionByRid(Integer id, String permissionId) throws Exception {
        this.roleMapper.deleteRolePermission(id);
        if (StringUtils.isNotBlank(permissionId)) {
            String[] permissionIds = permissionId.split(",");
            for (String pid : permissionIds) {
                this.roleMapper.insertPermission(id, Integer.valueOf(ObjectUtil.getInt(pid, 0)));
            }
        }
    }

    public List<Map<String, Object>> getDataRule() throws Exception {
        return this.roleMapper.getDataRule();
    }

    public List<Map<String, Object>> getMenus() throws Exception {
        return this.roleMapper.getMenus();
    }

    public Integer insertMenu(String name, String action, String url, String cls, Integer parentId, Integer level) throws Exception {
        Integer count = this.roleMapper.getNameCount(name, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("菜单【" + name + "】已存在");
        }
        Perm p = new Perm();
        p.setId(getChildId(level));
        p.setName(name);
        p.setAction(action == null ? "" : action);
        p.setUrl(url);
        p.setCls(cls);
        p.setParentId(Integer.valueOf(parentId == null ? 0 : parentId.intValue()));
        p.setSort(Integer.valueOf(this.roleMapper.maxSort().intValue() + 1));
        p.setLevel(level);
        this.roleMapper.insertMenu(p);
        this.roleMapper.insertPermission(1, p.getId());
        return p.getId();
    }

    public void updMenu(Integer id, String name, String action, String url, String cls, Integer parentId, Integer level) throws Exception {
        Integer count = this.roleMapper.getNameCount(name, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("菜单【" + name + "】已存在");
        }
        Perm p = new Perm();
        p.setId(id);
        p.setName(name);
        p.setAction(action == null ? "" : action);
        p.setUrl(url);
        p.setCls(cls);
        p.setParentId(Integer.valueOf(parentId == null ? 0 : parentId.intValue()));
        this.roleMapper.updMenu(p);
    }

    @Transactional
    public void delMenu(Integer id) throws Exception {
        this.roleMapper.delRoleMenu(id);
        this.roleMapper.delMenu(id);
    }

    private Integer getChildId(Integer level) throws Exception {
        return Integer.valueOf(this.roleMapper.getChildId(level).intValue() + 1);
    }

    public List<Map<String, Object>> getMenusForRole(Integer roleId) throws Exception {
        return this.roleMapper.getMenusForRole(roleId);
    }
}
